@@ -20,8 +20,12 @@ from ._names import PREBUILT_LOSSES, KERAS_LIST_LAYERS, PREBUILT_LAYERS, KERAS_L
 from .compiler import BaseNetCompiler
 from .database import BaseNetDatabase
 from .model import BaseNetModel
+from .feeder import BaseNetFeeder
 from ._loss_functions import window_diff
+from .__special__ import __version__
 
+
+from .metaheuristic import BaseNetHeuristic, BaseNetRandomSearch, BaseNetGenetic
 BaseNetCompiler.set_up_devices()
 # - x - x - x - x - x - x - x - x - x - x - x - x - x - x - #
 #                        END OF FILE                        #
