@@ -34,7 +34,7 @@ from ._names import KERAS_LOSSES, KERAS_LIST_LAYERS, PREBUILT_LOSSES, PREBUILT_L
 from .model import BaseNetModel
 from tensorflow.python.client import device_lib
 from pynvml.smi import nvidia_smi
-from .__special__ import __base_compiler__
+from .__special__ import __base_compiler__, __version__
 
 
 # -----------------------------------------------------------
@@ -172,10 +172,11 @@ class BaseNetCompiler:
         :param name: Name of the model.
         :param verbose: Print state and errors in the BaseNetCompiler.
         """
+        self.__version__ = __version__
         if layers is not None:
             self.layers: list[dict] = layers
         else:
-            self.layers: list[dict] = []
+            self.layers: list[dict] = list()
         self.compile_options: dict = compile_options
         self.devices: dict = devices
         self.io_shape: tuple = io_shape
@@ -207,7 +208,7 @@ class BaseNetCompiler:
                 if typ == 'cpu' or typ == 'gpu':
                     devices[dev['name']] = dev['state']
 
-        layers = []
+        layers = list()
         for __layer in compiler['layers']:
             for typ, layer in __layer.items():
                 if typ == 'layer':
@@ -215,7 +216,7 @@ class BaseNetCompiler:
                     if layer['shape'] is not None:
                         _layer['shape'] = tuple(layer['shape'])
                     else:
-                        _layer['shape'] = (None,)
+                        _layer['shape'] = ()  # Add None in previous versions.
                     _options = {}
                     if layer['options'] is not None:
                         for _option_ in layer['options']:
@@ -266,13 +267,13 @@ class BaseNetCompiler:
         _retval_[libdiv[0].name] = 'Train'
         return _retval_
 
-    def pop(self, index: int) -> dict:
+    def pop(self, index: int = 0) -> dict:
         """
         This method pops out a layer from the architecture.
         :param index: The place of the layer in the layers list.
         :return: The popped layer.
         """
-        popped = self.layers.pop(-index)
+        popped = self.layers.pop(- index - 1)
         return popped
 
     def add(self, layer: dict, where: int = -1):
@@ -323,10 +324,11 @@ class BaseNetCompiler:
 
         _layers_ = list()
         for layer in self.layers:
-            _options_ = list()
             for key, item in layer.items():
-                _options_.append({'option': {'name': key, 'value': item}})
-            _layers_.append({'layer': {'name': layer['name'], 'shape': layer['shape'], 'options': _options_}})
+                _options_ = list()
+                for key2, item2 in item[1].items():
+                    _options_.append({'option': {'name': key2, 'value': item2}})
+                _layers_.append({'layer': {'name': key, 'shape': item[0], 'options': _options_}})
 
         _yaml_full_ = {
             'name': self.name,
@@ -342,7 +344,7 @@ class BaseNetCompiler:
                 __compiler_path = f'{_compiler_path}.yaml'
             else:
                 __compiler_path = _compiler_path
-            with open(__compiler_path, 'wb') as file:
+            with open(__compiler_path, 'w') as file:
                 yaml.dump(yaml_on, file, default_flow_style=False)
             return True
         else:
@@ -362,7 +364,10 @@ class BaseNetCompiler:
                 __compiler_path = _compiler_path
             with open(__compiler_path, 'rb') as file:
                 compiler = pickle.load(file)
-            return compiler
+            if hasattr(compiler, '__version__'):
+                if compiler.__version__ == __version__:
+                    return compiler
+            return BaseNetCompiler._reversion(compiler)
         else:
             return None
 
@@ -379,7 +384,7 @@ class BaseNetCompiler:
             # Obtain the usable devices without OUT_OF_MEMORY errors.
             nvsmi = nvidia_smi.getInstance()
             query_devs = nvsmi.DeviceQuery('memory.free, name')['gpu']
-            devs = []
+            devs = list()
             total_vram = 0
             _total_ram = psutil.virtual_memory().free / 1000000
             total_usable_vram = _total_ram * let_free_ram
@@ -389,7 +394,7 @@ class BaseNetCompiler:
             sorted_devs = copy.copy(devs)
             sorted_devs.sort(key=lambda x: x.items())
             free_ram = total_usable_vram
-            usable_devices = []
+            usable_devices = list()
 
             for dev in sorted_devs:
                 k_i = dev.items()
@@ -493,17 +498,47 @@ class BaseNetCompiler:
                                                 f'tuple: (shapes,).')
                             return self.is_valid
 
+    @staticmethod
+    def _reversion(picked):
+        reversioned = BaseNetCompiler((), {}, {})
+        reversioned.layers = picked.layers
+        reversioned.name = picked.name
+        reversioned.compile_options = picked.compile_options
+        reversioned.devices = picked.devices
+        reversioned.io_shape = picked.io_shape
+        reversioned._check()
+        return reversioned
+
     # Build methods:
     def __repr__(self):
         return f'Compiler with {len(self.layers)} layers, options:\n{self.compile_options}'
 
     def __add__(self, other):
-        self.layers.append(other)
-        if not self._check(from_which=-1):
-            self.layers.pop(-1)
+        self.add(other)
+        return self
 
     def __bool__(self):
         return self.is_valid
+
+
+# -----------------------------------------------------------
+class Layer:
+    def __init__(self, layer: str, *shape: tuple, **kwargs: dict):
+        if layer in KERAS_LIST_LAYERS or layer in PREBUILT_LAYERS:
+            self.name: str = layer
+        else:
+            raise ValueError(f'Error in Layer: Layer {layer} not found in prebuilt_layers nor keras.layers.')
+
+        self.shape: tuple = shape
+        self.options: dict = kwargs
+
+    def __getitem__(self, item):
+        logging.warning(f'BaseNetLayer: The access to the item {item} is ignored, returning the Layer parameters. '
+                        f'Use the method .items() to get the values of a Layer.')
+        return {self.name: (self.shape, self.options)}
+
+    def items(self):
+        yield self.name, (self.shape, self.options)
 # - x - x - x - x - x - x - x - x - x - x - x - x - x - x - #
 #                        END OF FILE                        #
 # - x - x - x - x - x - x - x - x - x - x - x - x - x - x - #
